DownloadHistoryItemsRequest class

Download History Items Request JSON Object

Used to make /v1/history/download API request Requires historyItemIds parameter See ElevenLabs docs for more info

Annotations
  • @JsonSerializable.new()

Constructors

DownloadHistoryItemsRequest({required List<String> historyItemIds})
DownloadHistoryItemsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
historyItemIds List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited