Voice class

Voice JSON Object

Returned from /v1/voices endpoints Contains voice metadata See ElevenLabs docs for more info

Annotations
  • @JsonSerializable.new()

Constructors

Voice({List<String>? availableForTiers, required String category, String? description, required FineTuning fineTuning, required String name, String? language, Labels? labels, required String previewUrl, List<Sample>? samples, VoiceSettings? settings = const VoiceSettings(similarityBoost: 0.5, stability: 0.75), Sharing? sharing, required String voiceId})
Voice.fromJson(Map<String, dynamic> json)
factory

Properties

availableForTiers List<String>?
final
category String
final
description String?
final
fineTuning FineTuning
final
hashCode int
The hash code for this object.
no setterinherited
labels Labels?
final
language String?
final
name String
final
previewUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samples List<Sample>?
final
settings VoiceSettings?
final
sharing Sharing?
final
voiceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited